darkhistory.low_energy.lowE_photons.compute_fs — DarkHistory documentation

# darkhistory.low_energy.lowE_photons.compute_fs

`darkhistory.low_energy.lowE_photons.` `compute_fs`(photspec, x, dE_dVdt_inj, dt, method='old')

  Compute f(z) fractions for continuum photons, photoexcitation of HI, and photoionization of HI, HeI, HeII

  Given a spectrum of deposited photons, resolve its energy into continuum photons, continuum photons, HI excitation, and HI, HeI, HeII ionization in that order.

  Parameters: | photspec : Spectrum object spectrum of photons. spec.toteng() should return energy per baryon. x : list of floats number of (HI, HeI, HeII) divided by nH at redshift photspec.rs dE_dVdt_inj : float energy injection rate DM, dE/dVdt |_inj dt : float time in seconds over which these photons were deposited. method : {‘old’,’ion’,’new’} ‘old’: All photons >= 13.6eV ionize hydrogen, within [10.2, 13.6)eV excite hydrogen, < 10.2eV are labelled continuum. ‘ion’: Same as ‘old’, but now photons >= 13.6 can ionize HeI and HeII also. ‘new’: Same as ‘ion’, but now [10.2, 13.6)eV photons treated more carefully.
  Returns: | tuple of floats Ratio of deposited energy to a given channel over energy deposited by DM. The order of the channels is {continuum photons, HI excitation, HI ionization, HeI ion, HeII ion}

#### Previous topic

darkhistory.low_energy.lowE_photons

#### Next topic

darkhistory.low_energy.lowE_photons.getf_continuum

### This Page

Show Source